CompiledPattern

Struct CompiledPattern 

pub struct CompiledPattern { /* private fields */ }

Implementations

Source

impl CompiledPattern

pub fn compile(pattern: &str) -> Result<Self, ParseError>

Compile a TEL pattern into validated typed segments.

Errors

Returns ParseError::InvalidPattern when the source contains an unsupported or semantically invalid TEL construct.

pub fn source(&self) -> &str

pub fn token_info(&self) -> &[TokenInfo]

pub const fn parsed(&self) -> &ParsedPattern

pub fn segments(&self) -> &[TelSegment]

pub const fn class_plan(&self) -> &CompiledClassPlan

pub fn class_segments(&self) -> &[CompiledClassSegment]

pub fn class_pattern(&self, mode: MatchMode) -> &str

pub fn class_regex(&self, mode: MatchMode) -> Result<&Pcre2Regex, ParseError>

Return the lazily compiled class-comparator regex for the requested match mode.

Errors

Returns ParseError::InvalidPattern if the generated class comparator regex is invalid.